@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: kerning.pl 825 2006-04-27 20:06:21Z eugeniy $
+# $Id: kerning.pl 10 2004-06-09 20:04:28Z src $
 
 %chardata = ();
 %encmap = ();
@@ -33,7 +33,7 @@ foreach $enc (sort { $a <=> $b } keys %encmap) {
   my $char = $encmap{$enc};
   printf '%-16s %5d', $char, $enc;
   print ' kerning:';
-  my $kern = $chardata{$char}{'kernsslifo'};
+  my $kern = $chardata{$char}{'kernsslif'};
   if ($kern) {
     my @kern = split (/\s+/, $kern);
     my $kern_str;
